#Rem
#Rem $Header:
#Rem
#Rem Desc: Sql Server Table creation script for PROFILE
#Rem

#ECHO %!b_msgs[B_ECHO_CREATE_SLA_COMMON]

#REM
#REM Map SYNONYMS to DBCOMMON global variables
#REM
#DEFINE TAB_QUAL {{DBCOMMON:GlobalTabQual}}
#DEFINE ON_TABLE_SEGMENT {{DBCOMMON:GlobalTableLocation}}
#DEFINE PK_INDEX_CLAUSE {{DBCOMMON:GlobalPrimaryKeyIndexLocation}}
#DEFINE ON_INDEX_SEGMENT {{DBCOMMON:GlobalIndexLocation}}
#DEFINE COMMAND_TERMINATOR GO
#DEFINE COMMAND_TERMINATION_MODE START_OF_LINE

#SUPPRESS -15036
#SUPPRESS -3701

#REM No data is being returned.
#SUPPRESS -100

CREATE TABLE <<TAB_QUAL>>.SLA_TERM (
       TERM_ID                  INTEGER NOT NULL,
       TERM_NAME                VARCHAR(20) NOT NULL,
       DESCRIPTION              VARCHAR(254) NULL,
       CALENDAR_ID              INTEGER NULL,
       SECONDS_TO_BREACH        INTEGER NOT NULL,
       RELATIVE_TO              INTEGER NULL,
       BASE_CONDITION           TEXT NULL,
       LOCATION_CONDITION       TEXT NULL,
       EXIT_CONDITION           TEXT NULL,
       CONSTRAINT XPKSLA_TERM PRIMARY KEY (TERM_ID) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

CREATE TABLE <<TAB_QUAL>>.SLA_SCHEDULE (
       EVENT_ID                 INTEGER NOT NULL,
       EVENT_NAME               VARCHAR(20) NOT NULL,
       DESCRIPTION              VARCHAR(254) NULL,
       TIME_TO_FIRE             INTEGER NOT NULL,
       TERM_ID                  INTEGER NULL,
       CONSTRAINT XPKSLA_SCHEDULE PRIMARY KEY (EVENT_ID) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go       

CREATE TABLE <<TAB_QUAL>>.SLA_ACTION (
       ACTION_ID                INTEGER NOT NULL,
       ACTION_NAME              VARCHAR(20) NOT NULL,
       SEQUENCE_NUMBER          INTEGER NOT NULL,
       ACTION_TYPE              INTEGER NOT NULL,
       ACTION_TARGET            VARCHAR(254) NULL,
       NOTIFICATION_TYPE        CHAR(15) NULL,
       IS_GROUP                 BOOLEAN NULL,
       ACTION_TITLE             VARCHAR(40) NULL,
       ACTION_TEXT              TEXT NULL,
       EVENT_ID                 INTEGER NULL,
       CONSTRAINT XPKSLA_ACTION PRIMARY KEY (ACTION_ID) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

CREATE TABLE <<TAB_QUAL>>.SLA_CALENDAR (
       CALENDAR_ID             INTEGER NOT NULL,
       CALENDAR_NAME           VARCHAR(20) NOT NULL,
       DESCRIPTION             VARCHAR(254) NULL,
       START_DATE              DATE NULL,
       END_DATE                DATE NULL,
       NEXT_CALENDAR_ID        INTEGER NULL,
       CONSTRAINT XPKSLA_CALENDAR PRIMARY KEY (CALENDAR_ID) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

CREATE TABLE <<TAB_QUAL>>.SLA_DAY (
       DAY_ID                 INTEGER NOT NULL,
       DAY_NAME               VARCHAR(15) NOT NULL,
       DESCRIPTION            VARCHAR(254) NULL,
       BUSINESS_HOURS         VARCHAR(96) NOT NULL,
       CONSTRAINT XPKSLA_DAY PRIMARY KEY (DAY_ID) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

CREATE TABLE <<TAB_QUAL>>.SLA_YEAR (
       CALENDAR_ID            INTEGER NOT NULL,
       DAY_ID                 INTEGER NOT NULL,
       YEAR_DAY               INTEGER NOT NULL,
       DAY_TYPE_NAME          VARCHAR(15) NULL,
       CONSTRAINT XPKSLA_YEAR PRIMARY KEY (CALENDAR_ID, DAY_ID, YEAR_DAY) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go                          

CREATE TABLE <<TAB_QUAL>>.ACTIVE_SLA (
       ACTIVE_SLA_ID          INTEGER NOT NULL,
       TERM_ID                INTEGER NULL,
       REFERENCE_ID           VARCHAR(15) NOT NULL,
       RELATIVE_TO            INTEGER NOT NULL,
       SLA_STATE              INTEGER NOT NULL,
       BREACH_DATE            DATE NULL,
       BREACH_TIME            TIME NULL,
       NEXT_SCHEDULE_ID       INTEGER NULL,
       NEXT_FIRE_DATE         DATE NULL,
       NEXT_FIRE_TIME         TIME NULL,
       CONSTRAINT XPKACTIVE_SLA PRIMARY KEY (ACTIVE_SLA_ID) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

CREATE TABLE <<TAB_QUAL>>.BREACH_RELATIVE_TO (
       RELATIVE_TO             INTEGER NOT NULL,
       RELATION_NAME           VARCHAR(15) NOT NULL,
       TABLE_NAME              VARCHAR(30) NOT NULL,
       KEY_NAME                VARCHAR(30) NOT NULL,
       DATE_COL_NAME           VARCHAR(30) NOT NULL,
       TIME_COL_NAME           VARCHAR(30) NOT NULL,
       AUDIT_TABLE             VARCHAR(30) NOT NULL,
       CONSTRAINT XPKBREACH_RELATIVE PRIMARY KEY (RELATIVE_TO) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

CREATE TABLE <<TAB_QUAL>>.SLA_DAY_TYPE (
       DAY_TYPE_ID             INTEGER      NOT NULL,
       DAY_TYPE_NAME           VARCHAR(15)  NOT NULL,
       CONSTRAINT XPKSLA_DAY_TYPE PRIMARY KEY (DAY_TYPE_ID) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

CREATE TABLE <<TAB_QUAL>>.SLA_AUDIT_LOG (
       REFERENCE_ID            VARCHAR(15) NOT NULL,
       RELATIVE_TO             INTEGER NOT NULL,
       USER_ID                 CHAR(15) NOT NULL,
       ENTRY_DATE              DATE NOT NULL,
       ENTRY_TIME              TIME NOT NULL,
       ENTRY_TYPE              VARCHAR(50) NOT NULL,
       ENTRY                   VARCHAR(254) NULL,
       ENTRY_VALUE             VARCHAR(15) NULL,
       MODIFY_DATETIME         INTEGER NOT NULL,
       ENTRY_OVRFLW            TEXT NULL,       
       CONSTRAINT XPKSLA_AUDIT_LOG PRIMARY KEY (REFERENCE_ID, RELATIVE_TO) <<PK_INDEX_CLAUSE>>,
) <<ON_TABLE_SEGMENT>>
go

#REM #############################
#REM Add foreign key constraints
#REM #############################

ALTER TABLE <<TAB_QUAL>>.SLA_TERM
ADD CONSTRAINT R_131 FOREIGN KEY (CALENDAR_ID)
               REFERENCES <<TAB_QUAL>>.SLA_CALENDAR
go

ALTER TABLE <<TAB_QUAL>>.SLA_SCHEDULE
ADD CONSTRAINT R_132 FOREIGN KEY (TERM_ID)
               REFERENCES <<TAB_QUAL>>.SLA_TERM
go

ALTER TABLE <<TAB_QUAL>>.SLA_ACTION
ADD CONSTRAINT R_133 FOREIGN KEY (EVENT_ID)
               REFERENCES <<TAB_QUAL>>.SLA_SCHEDULE
go               
               
ALTER TABLE <<TAB_QUAL>>.SLA_YEAR
ADD CONSTRAINT R_134 FOREIGN KEY (DAY_ID)
               REFERENCES <<TAB_QUAL>>.SLA_DAY
go
               
ALTER TABLE <<TAB_QUAL>>.ACTIVE_SLA
ADD CONSTRAINT R_135 FOREIGN KEY (TERM_ID)
               REFERENCES <<TAB_QUAL>>.SLA_TERM
go
               
ALTER TABLE <<TAB_QUAL>>.ACTIVE_SLA
ADD CONSTRAINT R_136 FOREIGN KEY (NEXT_SCHEDULE_ID)
               REFERENCES <<TAB_QUAL>>.SLA_SCHEDULE (EVENT_ID)
go
               
ALTER TABLE <<TAB_QUAL>>.SLA_TERM
ADD CONSTRAINT R_137 FOREIGN KEY (RELATIVE_TO)
               REFERENCES <<TAB_QUAL>>.BREACH_RELATIVE_TO
go
               

#REM #############################
#REM Create indices
#REM #############################

CREATE UNIQUE INDEX XAK1SLA_TERM
  ON <<TAB_QUAL>>.SLA_TERM
  (
        TERM_NAME
  )
  <<ON_INDEX_SEGMENT>>
go

CREATE UNIQUE INDEX XAK1SLA_CALENDAR
  ON <<TAB_QUAL>>.SLA_CALENDAR
  (
        CALENDAR_NAME
  )
  <<ON_INDEX_SEGMENT>>
go

CREATE UNIQUE INDEX XAK1SLA_DAY
  ON <<TAB_QUAL>>.SLA_DAY
  (
        DAY_NAME
  )
  <<ON_INDEX_SEGMENT>>
go

CREATE UNIQUE INDEX XAK1SLA_DAY_TYPE
  ON <<TAB_QUAL>>.SLA_DAY_TYPE
  (
        DAY_TYPE_NAME
  )
  <<ON_INDEX_SEGMENT>>
go

CREATE UNIQUE INDEX XAK1RELATIVE_TO
  ON <<TAB_QUAL>>.BREACH_RELATIVE_TO
  (
        RELATION_NAME
  )
  <<ON_INDEX_SEGMENT>>
go

#REM #############################
#REM Insert initial data for SLA Module
#REM #############################

INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 1, '%!c_data[C_SUNDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 2, '%!c_data[C_MONDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 3, '%!c_data[C_TUESDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 4, '%!c_data[C_WEDNESDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 5, '%!c_data[C_THURSDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 6, '%!c_data[C_FRIDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 7, '%!c_data[C_SATURDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 8, '%!c_data[C_WEEKDAY_DB]')
GO
INSERT INTO <<TAB_QUAL>>.SLA_DAY_TYPE VALUES( 9, '%!c_data[C_WEEKEND_DB]')
GO
#REM (* ****************************************************************************************   
#REM    6.0-TSD-0014 Defect EQ21452
#REM    BREACH_RELATIVE_TO Entries differ between new and migrated tables.
#REM    RMS 25May00
#REM    **************************************************************************************** *)
#REM INSERT INTO <<TAB_QUAL>>.BREACH_RELATIVE_TO VALUES(1, '%!c_data[C_SLA_REL_NAME_1_DB]', 'PROBLEMS', 'PROBLEM_ID', 'OPEN_DATE', 'OPEN_TIME', 'SLA_AUDIT_LOG')
#REM GO
#REM INSERT INTO <<TAB_QUAL>>.BREACH_RELATIVE_TO VALUES(2, '%!c_data[C_SLA_REL_NAME_2_DB]', 'CALL', 'CALL_ID', 'CALL_BEGIN_DATE', 'CALL_BEGIN_TIME', 'SLA_AUDIT_LOG')
#REM GO

INSERT INTO <<TAB_QUAL>>.BREACH_RELATIVE_TO VALUES(1, '%!c_data[C_SLA_REL_NAME_1_DB]', 'PROBLEMS', 'PROBLEM_ID', 'OPEN_DATE', 'OPEN_TIME', 'SLA_AUDIT_LOG')
GO
INSERT INTO <<TAB_QUAL>>.BREACH_RELATIVE_TO VALUES(2, '%!c_data[C_SLA_REL_NAME_2_DB]', 'PROB_TRANSFER', 'PROBLEM_ID', 'TRANSFER_DATE', 'TRANSFER_TIME', 'SLA_AUDIT_LOG')
GO
INSERT INTO <<TAB_QUAL>>.BREACH_RELATIVE_TO VALUES(3, '%!c_data[C_SLA_REL_NAME_3_DB]', 'DISPATCH', 'CALL_ID', 'TRANSFER_DATE', 'TRANSFER_TIME', 'SLA_AUDIT_LOG')
GO

#REM (* ****************************************************************************************   
#REM    END 6.0-TSD-0014 Defect EQ21452
#REM    **************************************************************************************** *)
INSERT INTO <<TAB_QUAL>>.SAI_APP_PARAMS VALUES(19, 'SLA_PARAMS', 'SLA_ENABLED', 'FALSE', 0)
GO
INSERT INTO <<TAB_QUAL>>.COUNTERS (COUNTER_NAME, NEXT_NUMBER) VALUES('SLA_DAY', 1)
GO
INSERT INTO <<TAB_QUAL>>.COUNTERS (COUNTER_NAME, NEXT_NUMBER) VALUES('SLA_CALENDAR', 1)
GO
INSERT INTO <<TAB_QUAL>>.COUNTERS (COUNTER_NAME, NEXT_NUMBER) VALUES('SLA_TERM', 1)
GO
INSERT INTO <<TAB_QUAL>>.COUNTERS (COUNTER_NAME, NEXT_NUMBER) VALUES('SLA_EVENT', 1)
GO
INSERT INTO <<TAB_QUAL>>.COUNTERS (COUNTER_NAME, NEXT_NUMBER) VALUES('SLA_ACTION', 1)
GO
INSERT INTO <<TAB_QUAL>>.COUNTERS (COUNTER_NAME, NEXT_NUMBER) VALUES('ACTIVE_SLA', 1)
GO
INSERT INTO <<TAB_QUAL>>.COUNTERS (COUNTER_NAME, NEXT_NUMBER) VALUES('BREACH_RELATIVE', 1)
GO
