#Rem
#Rem $Header:
#Rem
#Rem Desc: 
#Rem

#REM Script executed if EFM is installed

#REM
#REM Map SYNONYMS to DBCOMMON global variables
#REM
#DEFINE TAB_QUAL {{DBCOMMON:GlobalTabQual}}
#DEFINE ON_TABLE_SEGMENT {{DBCOMMON:GlobalTableLocation}}
#DEFINE ON_INDEX_SEGMENT {{DBCOMMON:GlobalIndexLocation}}
#DEFINE PK_INDEX_CLAUSE {{DBCOMMON:GlobalIndexLocation}}
#DEFINE COMMAND_TERMINATOR GO
#DEFINE COMMAND_TERMINATION_MODE START_OF_LINE
#DEFINE PSITE_NUMBER {{peocfunc:psite_no}}

#REM Suppress 3731,3728 and 3701 will be returned if the constraint does not exist.
#REM Suppress 4902 and 4902 will be returned if the table does not exist.
#REM Suppress 100 No data is being returned.
#REM Suppress 208 Object not found
#REM Suppress 1779 Primary key is already defined.

#SUPPRESS -3731 
#SUPPRESS -4902
#SUPPRESS -3701
#SUPPRESS -100
#SUPPRESS -208
#SUPPRESS -1779
#SUPPRESS -3728

#REM ********************************************************
#REM Drop all constraints and triggers referencing PEOPLE
#REM ********************************************************

#ECHO %!b_msgs[B_ECHO_DROP_FK_PEOPLE_COMMON]

ALTER TABLE <<TAB_QUAL>>.INV_PEOPLE
	DROP CONSTRAINT I_164 
GO

ALTER TABLE <<TAB_QUAL>>.CONTRACT
    DROP  CONSTRAINT I_28
GO
    
ALTER TABLE <<TAB_QUAL>>.PEOPLE_CONTACT
	DROP CONSTRAINT I_17   
GO
    
ALTER TABLE <<TAB_QUAL>>.CHANGE
    DROP CONSTRAINT PO_AU  
GO

#REM R_126, R_127, R_129, I_29, TIV_2 found in trigger tD_PEOPLE

#REM I_29       : tU_PEOPLE, tI_ORG_MEMBERSHIP
#REM PO_ME      : tI_CCB_MEMBER, tU_CCB_MEMBER
#REM PO_CG_AS   : tI_CHANGE, tU_CHANGE
#REM PO_CG_RQ   : tI_CHANGE, tU_CHANGE
#REM PO_MO_CR   : tU_CHANGE_MODEL, tI_CHANGE_MODEL
#REM PO_MO_AS   : tU_CHANGE_MODEL, tI_CHANGE_MODEL
#REM PO_AC      : tU_ACTIONS, tI_ACTIONS
#REM PO_CA      : tU_APPROVAL, tI_APPROVAL
#REM PO_II      : tU_IMPACT_ITEM, tI_IMPACT_ITEM
#REM PO_MA      : tU_MODEL_APPROVAL, tI_MODEL_APPROVAL
#REM PO_MR      : tU_MODEL_SCHED_RES, tI_MODEL_SCHED_RES
#REM PO_SR      : tU_SCHED_RESOURCE, tI_SCHED_RESOURCE


DROP TRIGGER tU_PEOPLE
GO

DROP TRIGGER tD_PEOPLE
GO

DROP TRIGGER tI_ORG_MEMBERSHIP
GO

DROP TRIGGER tU_ORG_MEMBERSHIP
GO

DROP TRIGGER tI_CCB_MEMBER
GO

DROP TRIGGER tU_CCB_MEMBER
GO

DROP TRIGGER tI_CHANGE
GO

DROP TRIGGER tU_CHANGE
GO

DROP TRIGGER tI_CHANGE_MODEL
GO

DROP TRIGGER tU_CHANGE_MODEL
GO

DROP TRIGGER tI_ACTIONS
GO

DROP TRIGGER tU_ACTIONS
GO

DROP TRIGGER tI_APPROVAL
GO

DROP TRIGGER tU_APPROVAL
GO

DROP TRIGGER tI_IMPACT_ITEM
GO

DROP TRIGGER tU_IMPACT_ITEM
GO

DROP TRIGGER tI_MODEL_APPROVAL
GO

DROP TRIGGER tU_MODEL_APPROVAL
GO

DROP TRIGGER tI_MODEL_SCHED_RES
GO

DROP TRIGGER tU_MODEL_SCHED_RES
GO

DROP TRIGGER tI_SCHED_RESOURCE
GO

DROP TRIGGER tU_SCHED_RESOURCE
GO

ALTER TABLE <<TAB_QUAL>>.PEOPLE
    DROP CONSTRAINT PK_PEOPLE  
GO

#REM ********************************************************
#REM End drop of constraints and triggers referencing PEOPLE
#REM ********************************************************


#REM ********************************************************
#REM Move people to old_people, new_people to people
#REM ********************************************************

#ECHO %!b_msgs[B_ECHO_RENAME_PEOPLE_COMMON]

DROP TABLE <<TAB_QUAL>>.OLD_PEOPLE 
GO

sp_rename PEOPLE, OLD_PEOPLE
GO

sp_rename NEW_PEOPLE, PEOPLE


#REM #############################
#REM  Altering USERS and ORGANIZATION table.
#REM #############################

#ECHO %!b_msgs[B_ECHO_ALTER_USER_ORG_COMMON]

ALTER TABLE <<TAB_QUAL>>.USERS ADD TIMEZONE_ID CHAR(30) NULL
GO

ALTER TABLE <<TAB_QUAL>>.ORGANIZATION ADD A_ORG_KNWLDG_MASK INTEGER NULL
GO

ALTER TABLE <<TAB_QUAL>>.ORG_MEMBERSHIP ADD DEFAULT_ORG BOOLEAN NULL
GO

#REM #############################
#REM  Create indices.
#REM #############################

DROP INDEX <<TAB_QUAL>>.XAKCONTRACT_ADDRESS
GO

DROP INDEX <<TAB_QUAL>>.XAKCONTRACT_HISTORY
GO

DROP INDEX <<TAB_QUAL>>.XAKPEOPLE 
GO

CREATE INDEX XIECONTRACT_ADDR
  ON <<TAB_QUAL>>.CONTRACT_ADDRESS
(
       CONTRACT_ID                    
) <<ON_INDEX_SEGMENT>>
go
   
CREATE INDEX XIECONTRACT_HIST
  ON <<TAB_QUAL>>.CONTRACT_HISTORY
(
       CONTRACT_ID   
)<<ON_INDEX_SEGMENT>>
go  

#REM #############################
#REM  Drop constraints for Contacts - 61, 110, 121.
#REM #############################

#REM Drop RI between Contacts and Location

ALTER TABLE <<TAB_QUAL>>.CONTACTS
    DROP CONSTRAINT R_61
GO
    
#REM Drop RI between call and contacts    
ALTER TABLE <<TAB_QUAL>>.CALL
    DROP CONSTRAINT R_110
GO

#REM Drop RI between contacts and problem
ALTER TABLE <<TAB_QUAL>>.PROBLEMS
    DROP CONSTRAINT R_121
GO


#REM #############################
#REM  Update related people tables with new people_id
#REM #############################

#ECHO %!b_msgs[B_ECHO_UPD_PEO_ASS_CHG_COMMON]

UPDATE <<TAB_QUAL>>.ACTIONS SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.APPROVAL SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.CCB_MEMBER SET MEMBER_ID = MEMBER_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.CHANGE SET ASSIGNED_TO = ASSIGNED_TO + <<PSITE_NUMBER>>, 
    AUTHOR = AUTHOR + <<PSITE_NUMBER>>, REQUESTER_ID = REQUESTER_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.CHANGE_MODEL SET CREATOR = CREATOR + <<PSITE_NUMBER>>, 
    ASSIGNED_TO = ASSIGNED_TO + <<PSITE_NUMBER>>
GO
                      
UPDATE <<TAB_QUAL>>.CONTRACT SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.EXTERNAL_MAP SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.IMPACT_ITEM SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.INV_PEOPLE SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.MODEL_APPROVAL SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.MODEL_SCHED_RES SET RESOURCE_ID = RESOURCE_ID + <<PSITE_NUMBER>>
                    WHERE RESOURCE_TYPE = 'P'
GO

UPDATE <<TAB_QUAL>>.ORG_MEMBERSHIP SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.REPORT_DETAIL SET PEOPLE_ID = PEOPLE_ID + <<PSITE_NUMBER>>
GO

UPDATE <<TAB_QUAL>>.SCHED_RESOURCE SET RESOURCE_ID = RESOURCE_ID + <<PSITE_NUMBER>>
                    WHERE RESOURCE_TYPE = 'P'
GO

#REM #############################
#REM  Updating PEOPLE_ID
#REM #############################

#ECHO %!b_msgs[B_ECHO_UPD_PEO_NUG_EWUSR_COMMON]

UPDATE <<TAB_QUAL>>.NOTIFY_USER_GROUP SET PEOPLE_ID = 
        (SELECT PEOPLE_ID 
        FROM <<TAB_QUAL>>.PEOPLE_LOCATION A
        WHERE <<TAB_QUAL>>.NOTIFY_USER_GROUP.USER_GROUP_ID = A.CONTACT_ID 
        AND <<TAB_QUAL>>.NOTIFY_USER_GROUP.LOCATION_ID = A.LOCATION_ID )
GO

UPDATE <<TAB_QUAL>>.NOTIFY_USER_GROUP
    SET PEOPLE_ID = (SELECT PEOPLE_ID 
    FROM <<TAB_QUAL>>.USERS A
    WHERE USER_GROUP_ID = A.USER_ID )
#REM (* ****************************************************************************************   
#REM    6.0-TSD-0014 Defect EQ21007
#REM    NOTIFY_USER_GROUP.PEOPLE_ID Updated to NULL by people migration
#REM    RMS 31May00
#REM    **************************************************************************************** *)
	 WHERE PEOPLE_ID IS NULL
#REM (* ****************************************************************************************   
#REM    END 6.0-TSD-0014 Defect EQ21007
#REM    **************************************************************************************** *)
GO    

UPDATE <<TAB_QUAL>>.EWEB_USER_RIGHTS
    SET PEOPLE_ID = (SELECT PEOPLE_ID
    FROM <<TAB_QUAL>>.PEOPLE A
    WHERE A.ACCESS_ID = <<TAB_QUAL>>.EWEB_USER_RIGHTS.WEB_ID )
    WHERE PEOPLE_ID = -1
GO

#REM #############################
#REM  Adding foreign key constraints
#REM #############################

#ECHO %!b_msgs[B_ECHO_ADD_FK_PEOPLE_COMMON]
#ECHO %!b_msgs[B_ECHO_ADD_FK_TRG_NEW_COMMON]

ALTER TABLE <<TAB_QUAL>>.USERS
    ADD CONSTRAINT R_130 FOREIGN KEY (TIMEZONE_ID)
    REFERENCES <<TAB_QUAL>>.TIMEZONES
go

ALTER TABLE <<TAB_QUAL>>.PEOPLE_LOCATION
    ADD CONSTRAINT R_128 FOREIGN KEY (LOCATION_ID)
	REFERENCES <<TAB_QUAL>>.LOCATION
go  

ALTER TABLE <<TAB_QUAL>>.CONTRACT
    ADD  CONSTRAINT I_28 FOREIGN KEY  (PEOPLE_ID)
    REFERENCES <<TAB_QUAL>>.PEOPLE
go

ALTER TABLE <<TAB_QUAL>>.INV_PEOPLE
    ADD  CONSTRAINT I_164 FOREIGN KEY  (PEOPLE_ID)
    REFERENCES <<TAB_QUAL>>.PEOPLE
go

#REM R_126, R_127, R_129, I_29, TIV_2 : tD_PEOPLE (tsd\mssqls.trg)

#REM I_29     : tU_PEOPLE, tI_ORG_MEMBERSHIP, tU_ORG_MEMBERSHIP
#REM PO_ME    : tI_CCB_MEMBER, tU_CCB_MEMBER
#REM PO_CG_AS : tI_CHANGE, tU_CHANGE 
#REM PO_CG_RQ : tI_CHANGE, tU_CHANGE
#REM PO_MO_CR : tU_CHANGE_MODEL, tI_CHANGE_MODEL
#REM PO_MO_AS : tU_CHANGE_MODEL, tI_CHANGE_MODEL
#REM PO_AC    : tU_ACTIONS, tI_ACTIONS
#REM PO_CA    : tU_APPROVAL, tI_APPROVAL
#REM PO_II    : tU_IMPACT_ITEM, tI_IMPACT_ITEM
#REM PO_MA    : tU_MODEL_APPROVAL, tI_MODEL_APPROVAL
#REM PO_AU    : Missing from EE on sql server, sybase 
#REM PO_MR AND PO_SR: Missing from db2/2, oracle, informix
#REM PO_MR    : tU_MODEL_SCHED_RES, tI_MODEL_SCHED_RES
#REM PO_SR    : tU_SCHED_RESOURCE, tI_SCHED_RESOURCE
#REM W_1      : tI_EWEB_USER_RIGHTS, tU_EWEB_USER_RIGHTS

#REM ******************************************************
#REM    tI_CCB_MEMBER   
#REM
#REM    PO_ME
#REM ******************************************************

create trigger tI_CCB_MEMBER on <<TAB_QUAL>>.CCB_MEMBER for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* INSERT trigger on <<TAB_QUAL>>.CCB_MEMBER */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_ME CCB_MEMBER ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(MEMBER_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.MEMBER_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CCB_MEMBER_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_CONTROL_BOA CC_ME CCB_MEMBER ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CCB_MEMBER_2_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_CCB_MEMBER   
#REM
#REM    PO_ME
#REM ******************************************************

create trigger tU_CCB_MEMBER on <<TAB_QUAL>>.CCB_MEMBER for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.CCB_MEMBER */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insCCB_NAME varchar(40), 
           @insMEMBER_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_ME CCB_MEMBER ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(MEMBER_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.MEMBER_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CCB_MEMBER_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_CONTROL_BOA CC_ME CCB_MEMBER ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CCB_MEMBER_2_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_CHANGE  
#REM
#REM    PO_CG_AS, PO_CG_RQ
#REM ******************************************************

create trigger tI_CHANGE on <<TAB_QUAL>>.CHANGE for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* INSERT trigger on <<TAB_QUAL>>.CHANGE */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* LOCATION LO_CG CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(LOCATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.LOCATION
        where
          /* %JoinFKPK(inserted,LOCATION) */
          inserted.LOCATION_ID = <<TAB_QUAL>>.LOCATION.LOCATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.LOCATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_CG_AS CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ASSIGNED_TO)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.ASSIGNED_TO = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ASSIGNED_TO is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_CG_RQ CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(REQUESTER_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.REQUESTER_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.REQUESTER_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_CG_AR CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESPONSIBLE_AREA)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.RESPONSIBLE_AREA = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RESPONSIBLE_AREA is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_4_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_CG_CC CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(COST_CENTER)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.COST_CENTER = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.COST_CENTER is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_5_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CATEGORY CY_CG CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CATEGORY)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CATEGORY
        where
          /* %JoinFKPK(inserted,CATEGORY) */
          inserted.CATEGORY = <<TAB_QUAL>>.CATEGORY.CATEGORY
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_6_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* RISK_CODES RC_CG CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RISK_CODE)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.RISK_CODES
        where
          /* %JoinFKPK(inserted,RISK_CODES) */
          inserted.RISK_CODE = <<TAB_QUAL>>.RISK_CODES.RISK_CODE
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RISK_CODE is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_7_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_STATUS ST_CG CHANGE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(STATUS_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_STATUS
        where
          /* %JoinFKPK(inserted,CHANGE_STATUS) */
          inserted.STATUS_ID = <<TAB_QUAL>>.CHANGE_STATUS.STATUS_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_8_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_CHANGE  
#REM
#REM    PO_CG_AS, PO_CG_RQ
#REM ******************************************************

create trigger tU_CHANGE on <<TAB_QUAL>>.CHANGE for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.CHANGE */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insCHANGE_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_CT_CH CHANGE_TREE ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.CHANGE_TREE
      where
        /*  %JoinFKPK(CHANGE_TREE,deleted," = "," and") */
        <<TAB_QUAL>>.CHANGE_TREE.PARENT_CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_CT_PA CHANGE_TREE ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.CHANGE_TREE
      where
        /*  %JoinFKPK(CHANGE_TREE,deleted," = "," and") */
        <<TAB_QUAL>>.CHANGE_TREE.CHILD_CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CH_CA CHANGE_ATTACHMENT ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.CHANGE_ATTACHMENT
      where
        /*  %JoinFKPK(CHANGE_ATTACHMENT,deleted," = "," and") */
        <<TAB_QUAL>>.CHANGE_ATTACHMENT.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_CA APPROVAL ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.APPROVAL
      where
        /*  %JoinFKPK(APPROVAL,deleted," = "," and") */
        <<TAB_QUAL>>.APPROVAL.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_4_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_II IMPACT_ITEM ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.IMPACT_ITEM
      where
        /*  %JoinFKPK(IMPACT_ITEM,deleted," = "," and") */
        <<TAB_QUAL>>.IMPACT_ITEM.IMP_CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_5_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_CM CHANGE_MATRIX ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.CHANGE_MATRIX
      where
        /*  %JoinFKPK(CHANGE_MATRIX,deleted," = "," and") */
        <<TAB_QUAL>>.CHANGE_MATRIX.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_6_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_EI INV_EFFECT ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.INV_EFFECT
      where
        /*  %JoinFKPK(INV_EFFECT,deleted," = "," and") */
        <<TAB_QUAL>>.INV_EFFECT.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_7_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_AP ASSOCIATED_PROBLEM ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.ASSOCIATED_PROBLEM
      where
        /*  %JoinFKPK(ASSOCIATED_PROBLEM,deleted," = "," and") */
        <<TAB_QUAL>>.ASSOCIATED_PROBLEM.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_8_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_CH CHANGE_HISTORY ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.CHANGE_HISTORY
      where
        /*  %JoinFKPK(CHANGE_HISTORY,deleted," = "," and") */
        <<TAB_QUAL>>.CHANGE_HISTORY.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_9_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_IS IMPLEMENT_SCHEDULE ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.IMPLEMENT_SCHEDULE
      where
        /*  %JoinFKPK(IMPLEMENT_SCHEDULE,deleted," = "," and") */
        <<TAB_QUAL>>.IMPLEMENT_SCHEDULE.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_10_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_IM IMPACT ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(CHANGE_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.IMPACT
      where
        /*  %JoinFKPK(IMPACT,deleted," = "," and") */
        <<TAB_QUAL>>.IMPACT.CHANGE_ID = deleted.CHANGE_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_11_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* LOCATION LO_CG CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(LOCATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.LOCATION
        where
          /* %JoinFKPK(inserted,LOCATION) */
          inserted.LOCATION_ID = <<TAB_QUAL>>.LOCATION.LOCATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.LOCATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_12_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_CG_AS CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ASSIGNED_TO)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.ASSIGNED_TO = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ASSIGNED_TO is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_13_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_CG_RQ CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(REQUESTER_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.REQUESTER_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.REQUESTER_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_14_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_CG_AR CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESPONSIBLE_AREA)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.RESPONSIBLE_AREA = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RESPONSIBLE_AREA is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_15_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_CG_CC CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(COST_CENTER)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.COST_CENTER = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.COST_CENTER is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_16_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CATEGORY CY_CG CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CATEGORY)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CATEGORY
        where
          /* %JoinFKPK(inserted,CATEGORY) */
          inserted.CATEGORY = <<TAB_QUAL>>.CATEGORY.CATEGORY
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_17_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* RISK_CODES RC_CG CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RISK_CODE)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.RISK_CODES
        where
          /* %JoinFKPK(inserted,RISK_CODES) */
          inserted.RISK_CODE = <<TAB_QUAL>>.RISK_CODES.RISK_CODE
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RISK_CODE is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_18_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_STATUS ST_CG CHANGE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(STATUS_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_STATUS
        where
          /* %JoinFKPK(inserted,CHANGE_STATUS) */
          inserted.STATUS_ID = <<TAB_QUAL>>.CHANGE_STATUS.STATUS_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_19_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_CHANGE_MODEL 
#REM
#REM    PO_MO_CR, PO_MO_AS
#REM ******************************************************

create trigger tU_CHANGE_MODEL on <<TAB_QUAL>>.CHANGE_MODEL for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:39 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.CHANGE_MODEL */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insMODEL_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_MODEL CH_MA MODEL_ATTACHMENT ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(MODEL_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.MODEL_ATTACHMENT
      where
        /*  %JoinFKPK(MODEL_ATTACHMENT,deleted," = "," and") */
        <<TAB_QUAL>>.MODEL_ATTACHMENT.MODEL_ID = deleted.MODEL_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_MODEL MO_MA MODEL_APPROVAL ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(MODEL_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.MODEL_APPROVAL
      where
        /*  %JoinFKPK(MODEL_APPROVAL,deleted," = "," and") */
        <<TAB_QUAL>>.MODEL_APPROVAL.MODEL_ID = deleted.MODEL_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_MODEL MO_MT_PA MODEL_TREE ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(MODEL_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.MODEL_TREE
      where
        /*  %JoinFKPK(MODEL_TREE,deleted," = "," and") */
        <<TAB_QUAL>>.MODEL_TREE.PARENT_MODEL_ID = deleted.MODEL_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_MODEL MO_MT_CH MODEL_TREE ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(MODEL_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.MODEL_TREE
      where
        /*  %JoinFKPK(MODEL_TREE,deleted," = "," and") */
        <<TAB_QUAL>>.MODEL_TREE.CHILD_MODEL_ID = deleted.MODEL_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_4_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_MODEL MO_MI MODEL_IMPACT ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(MODEL_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.MODEL_IMPACT
      where
        /*  %JoinFKPK(MODEL_IMPACT,deleted," = "," and") */
        <<TAB_QUAL>>.MODEL_IMPACT.MODEL_ID = deleted.MODEL_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_5_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_MODEL MO_MS MODEL_SCHEDULE ON PARENT UPDATE RESTRICT */
  if
    /* %ParentPK(" or",update) */
    update(MODEL_ID)
  begin
    if exists (
      select * from deleted,<<TAB_QUAL>>.MODEL_SCHEDULE
      where
        /*  %JoinFKPK(MODEL_SCHEDULE,deleted," = "," and") */
        <<TAB_QUAL>>.MODEL_SCHEDULE.MODEL_ID = deleted.MODEL_ID
    )
    begin
      select @errno  = 30005,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_6_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* ORGANIZATION OR_MO_AR CHANGE_MODEL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESPONSIBLE_AREA)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.RESPONSIBLE_AREA = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RESPONSIBLE_AREA is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_7_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* ORGANIZATION OR_MO_CC CHANGE_MODEL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(COST_CENTER)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.COST_CENTER = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.COST_CENTER is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_8_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* PEOPLE PO_MO_CR CHANGE_MODEL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CREATOR)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.CREATOR = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CREATOR is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_9_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* PEOPLE PO_MO_AS CHANGE_MODEL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ASSIGNED_TO)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.ASSIGNED_TO = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ASSIGNED_TO is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_10_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CATEGORY CY_MO CHANGE_MODEL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CATEGORY)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CATEGORY
        where
          /* %JoinFKPK(inserted,CATEGORY) */
          inserted.CATEGORY = <<TAB_QUAL>>.CATEGORY.CATEGORY
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CATEGORY is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_11_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* RISK_CODES RC_MO CHANGE_MODEL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RISK_CODE)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.RISK_CODES
        where
          /* %JoinFKPK(inserted,RISK_CODES) */
          inserted.RISK_CODE = <<TAB_QUAL>>.RISK_CODES.RISK_CODE
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RISK_CODE is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_12_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_STATUS ST_MO CHANGE_MODEL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(STATUS_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_STATUS
        where
          /* %JoinFKPK(inserted,CHANGE_STATUS) */
          inserted.STATUS_ID = <<TAB_QUAL>>.CHANGE_STATUS.STATUS_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.STATUS_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_CHANGE_MODEL_13_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go


#REM ******************************************************
#REM    tI_CHANGE_MODEL 
#REM
#REM    PO_MO_CR, PO_MO_AS
#REM ******************************************************

create trigger tI_CHANGE_MODEL on <<TAB_QUAL>>.CHANGE_MODEL for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:39 1997 */
/* INSERT trigger on <<TAB_QUAL>>.CHANGE_MODEL */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_MO_AR CHANGE_MODEL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESPONSIBLE_AREA)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.RESPONSIBLE_AREA = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RESPONSIBLE_AREA is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_MODEL_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_MO_CC CHANGE_MODEL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(COST_CENTER)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.COST_CENTER = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.COST_CENTER is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_MODEL_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* PEOPLE PO_MO_CR CHANGE_MODEL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CREATOR)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.CREATOR = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CREATOR is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_MODEL_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* PEOPLE PO_MO_AS CHANGE_MODEL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ASSIGNED_TO)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.ASSIGNED_TO = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ASSIGNED_TO is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_MODEL_4_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CATEGORY CY_MO CHANGE_MODEL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CATEGORY)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CATEGORY
        where
          /* %JoinFKPK(inserted,CATEGORY) */
          inserted.CATEGORY = <<TAB_QUAL>>.CATEGORY.CATEGORY
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CATEGORY is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_MODEL_5_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* RISK_CODES RC_MO CHANGE_MODEL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RISK_CODE)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.RISK_CODES
        where
          /* %JoinFKPK(inserted,RISK_CODES) */
          inserted.RISK_CODE = <<TAB_QUAL>>.RISK_CODES.RISK_CODE
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.RISK_CODE is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_MODEL_6_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE_STATUS ST_MO CHANGE_MODEL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(STATUS_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_STATUS
        where
          /* %JoinFKPK(inserted,CHANGE_STATUS) */
          inserted.STATUS_ID = <<TAB_QUAL>>.CHANGE_STATUS.STATUS_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.STATUS_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_CHANGE_MODEL_7_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go
          
#REM ******************************************************
#REM    tI_ACTIONS  
#REM
#REM    PO_AC
#REM ******************************************************


create trigger tI_ACTIONS on <<TAB_QUAL>>.ACTIONS for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* INSERT trigger on <<TAB_QUAL>>.ACTIONS */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:37 1997 */
  /* ORGANIZATION OR_AC ACTIONS ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ORGANIZATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_ACTIONS_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_CONTROL_BOA CC_AC ACTIONS ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CCB_NAME is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_ACTIONS_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_AC ACTIONS ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_ACTIONS_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* RULES RU_AC ACTIONS ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RULE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.RULES
        where
          /* %JoinFKPK(inserted,RULES) */
          inserted.RULE_ID = <<TAB_QUAL>>.RULES.RULE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_ACTIONS_4_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* COMMANDS CO_AC ACTIONS ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(COMMAND)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.COMMANDS
        where
          /* %JoinFKPK(inserted,COMMANDS) */
          inserted.COMMAND = <<TAB_QUAL>>.COMMANDS.COMMAND
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.COMMAND is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_ACTIONS_5_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go


#REM ******************************************************
#REM    tU_ACTIONS 
#REM
#REM    PO_AC
#REM ******************************************************


create trigger tU_ACTIONS on <<TAB_QUAL>>.ACTIONS for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.ACTIONS */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insACTION_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_AC ACTIONS ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ORGANIZATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_ACTIONS_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_CONTROL_BOA CC_AC ACTIONS ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CCB_NAME is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_ACTIONS_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_AC ACTIONS ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_ACTIONS_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* RULES RU_AC ACTIONS ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RULE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.RULES
        where
          /* %JoinFKPK(inserted,RULES) */
          inserted.RULE_ID = <<TAB_QUAL>>.RULES.RULE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_ACTIONS_4_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* COMMANDS CO_AC ACTIONS ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(COMMAND)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.COMMANDS
        where
          /* %JoinFKPK(inserted,COMMANDS) */
          inserted.COMMAND = <<TAB_QUAL>>.COMMANDS.COMMAND
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.COMMAND is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_ACTIONS_5_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_APPROVAL  
#REM
#REM    PO_CA
#REM ******************************************************

create trigger tU_APPROVAL on <<TAB_QUAL>>.APPROVAL for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.APPROVAL */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insAPPROVER_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_CA APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_APPROVAL_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_CONTROL_BOA CC_CA APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CCB_NAME is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_APPROVAL_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_CA APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ORGANIZATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_APPROVAL_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_CA APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CHANGE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE
        where
          /* %JoinFKPK(inserted,CHANGE) */
          inserted.CHANGE_ID = <<TAB_QUAL>>.CHANGE.CHANGE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_APPROVAL_4_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_APPROVAL  
#REM
#REM    PO_CA
#REM ******************************************************

create trigger tI_APPROVAL on <<TAB_QUAL>>.APPROVAL for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:38 1997 */
/* INSERT trigger on <<TAB_QUAL>>.APPROVAL */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* PEOPLE PO_CA APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_APPROVAL_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE_CONTROL_BOA CC_CA APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CCB_NAME is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_APPROVAL_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* ORGANIZATION OR_CA APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ORGANIZATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_APPROVAL_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  /* CHANGE CG_CA APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CHANGE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE
        where
          /* %JoinFKPK(inserted,CHANGE) */
          inserted.CHANGE_ID = <<TAB_QUAL>>.CHANGE.CHANGE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_APPROVAL_4_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:38 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_IMPACT_ITEM  
#REM
#REM    PO_II
#REM ******************************************************

create trigger tI_IMPACT_ITEM on <<TAB_QUAL>>.IMPACT_ITEM for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:39 1997 */
/* INSERT trigger on <<TAB_QUAL>>.IMPACT_ITEM */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* PEOPLE PO_II IMPACT_ITEM ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_IMPACT_ITEM_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE CG_II IMPACT_ITEM ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(IMP_CHANGE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE
        where
          /* %JoinFKPK(inserted,CHANGE) */
          inserted.IMP_CHANGE_ID = <<TAB_QUAL>>.CHANGE.CHANGE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.IMP_CHANGE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_IMPACT_ITEM_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* IMPACT IM_II IMPACT_ITEM ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CHANGE_ID) or
    update(IMP_CATEGORY)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.IMPACT
        where
          /* %JoinFKPK(inserted,IMPACT) */
          inserted.CHANGE_ID = <<TAB_QUAL>>.IMPACT.CHANGE_ID and
          inserted.IMP_CATEGORY = <<TAB_QUAL>>.IMPACT.IMP_CATEGORY
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_IMPACT_ITEM_3_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go


#REM ******************************************************
#REM    tU_IMPACT_ITEM  
#REM
#REM    PO_II
#REM ******************************************************

create trigger tU_IMPACT_ITEM on <<TAB_QUAL>>.IMPACT_ITEM for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:39 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.IMPACT_ITEM */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insITEM_ID char(15),
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* PEOPLE PO_II IMPACT_ITEM ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_IMPACT_ITEM_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* CHANGE CG_II IMPACT_ITEM ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(IMP_CHANGE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE
        where
          /* %JoinFKPK(inserted,CHANGE) */
          inserted.IMP_CHANGE_ID = <<TAB_QUAL>>.CHANGE.CHANGE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.IMP_CHANGE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_IMPACT_ITEM_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  /* IMPACT IM_II IMPACT_ITEM ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CHANGE_ID) or
    update(IMP_CATEGORY)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.IMPACT
        where
          /* %JoinFKPK(inserted,IMPACT) */
          inserted.CHANGE_ID = <<TAB_QUAL>>.IMPACT.CHANGE_ID and
          inserted.IMP_CATEGORY = <<TAB_QUAL>>.IMPACT.IMP_CATEGORY
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_IMPACT_ITEM_3_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:39 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_MODEL_APPROVAL  
#REM
#REM    PO_MA
#REM ******************************************************

create trigger tI_MODEL_APPROVAL on <<TAB_QUAL>>.MODEL_APPROVAL for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:40 1997 */
/* INSERT trigger on <<TAB_QUAL>>.MODEL_APPROVAL */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* PEOPLE PO_MA MODEL_APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_MODEL_APPROVAL_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* CHANGE_CONTROL_BOA CC_MA MODEL_APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CCB_NAME is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_MODEL_APPROVAL_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* ORGANIZATION OR_MA MODEL_APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ORGANIZATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_MODEL_APPROVAL_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* CHANGE_MODEL MO_MA MODEL_APPROVAL ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(MODEL_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_MODEL
        where
          /* %JoinFKPK(inserted,CHANGE_MODEL) */
          inserted.MODEL_ID = <<TAB_QUAL>>.CHANGE_MODEL.MODEL_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_MODEL_APPROVAL_4_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_MODEL_APPROVAL  
#REM
#REM    PO_MA
#REM ******************************************************

create trigger tU_MODEL_APPROVAL on <<TAB_QUAL>>.MODEL_APPROVAL for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:40 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.MODEL_APPROVAL */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insAPPROVER_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* PEOPLE PO_MA MODEL_APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.PEOPLE_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_MODEL_APPROVAL_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* CHANGE_CONTROL_BOA CC_MA MODEL_APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CCB_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_CONTROL_BOA
        where
          /* %JoinFKPK(inserted,CHANGE_CONTROL_BOA) */
          inserted.CCB_NAME = <<TAB_QUAL>>.CHANGE_CONTROL_BOA.CCB_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.CCB_NAME is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_MODEL_APPROVAL_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* ORGANIZATION OR_MA MODEL_APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          /* %JoinFKPK(inserted,ORGANIZATION) */
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    select @nullcnt = count(*) from inserted where
      inserted.ORGANIZATION_ID is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_MODEL_APPROVAL_3_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* CHANGE_MODEL MO_MA MODEL_APPROVAL ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(MODEL_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.CHANGE_MODEL
        where
          /* %JoinFKPK(inserted,CHANGE_MODEL) */
          inserted.MODEL_ID = <<TAB_QUAL>>.CHANGE_MODEL.MODEL_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_MODEL_APPROVAL_4_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_MODEL_SCHED_RES  
#REM
#REM    PO_MR
#REM ******************************************************

create trigger tI_MODEL_SCHED_RES on <<TAB_QUAL>>.MODEL_SCHED_RES for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:40 1997 */
/* INSERT trigger on <<TAB_QUAL>>.MODEL_SCHED_RES */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* MODEL_SCHEDULE MS_MR MODEL_SCHED_RES ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(MODEL_ID) or
    update(SCHED_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.MODEL_SCHEDULE
        where
          /* %JoinFKPK(inserted,MODEL_SCHEDULE) */
          inserted.MODEL_ID = <<TAB_QUAL>>.MODEL_SCHEDULE.MODEL_ID and
          inserted.SCHED_NAME = <<TAB_QUAL>>.MODEL_SCHEDULE.SCHED_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_MODEL_SCHED_RES_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* PEOPLE PO_MR MODEL_SCHED_RES ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESOURCE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.RESOURCE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_MODEL_SCHED_RES_2_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_MODEL_SCHED_RES  
#REM
#REM    PO_MR
#REM ******************************************************

create trigger tU_MODEL_SCHED_RES on <<TAB_QUAL>>.MODEL_SCHED_RES for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:40 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.MODEL_SCHED_RES */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insMODEL_ID int, 
           @insSCHED_NAME varchar(80), 
           @insRESOURCE_ID int, 
           @insRESOURCE_TYPE char(1),
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* MODEL_SCHEDULE MS_MR MODEL_SCHED_RES ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(MODEL_ID) or
    update(SCHED_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.MODEL_SCHEDULE
        where
          /* %JoinFKPK(inserted,MODEL_SCHEDULE) */
          inserted.MODEL_ID = <<TAB_QUAL>>.MODEL_SCHEDULE.MODEL_ID and
          inserted.SCHED_NAME = <<TAB_QUAL>>.MODEL_SCHEDULE.SCHED_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_MODEL_SCHED_RES_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  /* PEOPLE PO_MR MODEL_SCHED_RES ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESOURCE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.RESOURCE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_MODEL_SCHED_RES_2_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:40 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_SCHED_RESOURCE  
#REM
#REM    PO_SR
#REM ******************************************************

create trigger tI_SCHED_RESOURCE on <<TAB_QUAL>>.SCHED_RESOURCE for INSERT as
/* ERwin Builtin Tue Jun 17 09:00:41 1997 */
/* INSERT trigger on <<TAB_QUAL>>.SCHED_RESOURCE */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:41 1997 */
  /* PEOPLE PO_SR SCHED_RESOURCE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESOURCE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.RESOURCE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_SCHED_RESOURCE_DB]'
      goto error
    end
  end

  if
    update(RESOURCE_ID)
    select @validcnt = count(*) from inserted where inserted.RESOURCE_TYPE = 'O'
    if @validcnt > 0
   begin
      select @nullcnt = 0
      select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          CONVERT(CHAR,inserted.RESOURCE_ID) = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    
      if @validcnt + @nullcnt != @numrows
      begin
        select @errno  = 30002,
               @errmsg = '%!c_data[C_TRIG_TI_SCHED_RESOURCE_2_DB]'
        goto error
      end
   end

  /* ERwin Builtin Tue Jun 17 09:00:41 1997 */
  /* IMPLEMENT_SCHEDULE IS_SR SCHED_RESOURCE ON CHILD INSERT RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CHANGE_ID) or
    update(SCHED_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.IMPLEMENT_SCHEDULE
        where
          /* %JoinFKPK(inserted,IMPLEMENT_SCHEDULE) */
          inserted.CHANGE_ID = <<TAB_QUAL>>.IMPLEMENT_SCHEDULE.CHANGE_ID and
          inserted.SCHED_NAME = <<TAB_QUAL>>.IMPLEMENT_SCHEDULE.SCHED_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30002,
             @errmsg = '%!c_data[C_TRIG_TI_SCHED_RESOURCE_3_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:41 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go


#REM ******************************************************
#REM    tU_SCHED_RESOURCE  
#REM
#REM    PO_SR
#REM ******************************************************

create trigger tU_SCHED_RESOURCE on <<TAB_QUAL>>.SCHED_RESOURCE for UPDATE as
/* ERwin Builtin Tue Jun 17 09:00:41 1997 */
/* UPDATE trigger on <<TAB_QUAL>>.SCHED_RESOURCE */
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insCHANGE_ID int, 
           @insSCHED_NAME varchar(80), 
           @insRESOURCE_ID int, 
           @insRESOURCE_TYPE char(1),
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ERwin Builtin Tue Jun 17 09:00:41 1997 */
  /* PEOPLE PO_SR SCHED_RESOURCE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(RESOURCE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
        where
          /* %JoinFKPK(inserted,PEOPLE) */
          inserted.RESOURCE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_SCHED_RESOURCE_DB]'
      goto error
    end
  end

  if
    update(RESOURCE_ID)
    select @validcnt = count(*) from inserted where inserted.RESOURCE_TYPE = 'O'
    if @validcnt > 0
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
        where
          CONVERT(CHAR,inserted.RESOURCE_ID) = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID

    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_SCHED_RESOURCE_2_DB]'
      goto error
    end
  end

  /* ERwin Builtin Tue Jun 17 09:00:41 1997 */
  /* IMPLEMENT_SCHEDULE IS_SR SCHED_RESOURCE ON CHILD UPDATE RESTRICT */
  if
    /* %ChildFK(" or",update) */
    update(CHANGE_ID) or
    update(SCHED_NAME)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.IMPLEMENT_SCHEDULE
        where
          /* %JoinFKPK(inserted,IMPLEMENT_SCHEDULE) */
          inserted.CHANGE_ID = <<TAB_QUAL>>.IMPLEMENT_SCHEDULE.CHANGE_ID and
          inserted.SCHED_NAME = <<TAB_QUAL>>.IMPLEMENT_SCHEDULE.SCHED_NAME
    /* %NotnullFK(inserted," is null","select @nullcnt = count(*) from inserted where"," and") */
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = '%!c_data[C_TRIG_TU_SCHED_RESOURCE_3_DB]'
      goto error
    end
  end


  /* ERwin Builtin Tue Jun 17 09:00:41 1997 */
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_PEOPLE
#REM
#REM    I_29, W_1
#REM ******************************************************

create trigger tU_PEOPLE on <<TAB_QUAL>>.PEOPLE for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insPEOPLE_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* I_29 PEOPLE may be a member of ORG_MEMBERSHIP on PARENT UPDATE RESTRICT */
  if
    update(PEOPLE_ID)
  begin
    if exists (
      select * from deleted, <<TAB_QUAL>>.ORG_MEMBERSHIP
      where
        <<TAB_QUAL>>.ORG_MEMBERSHIP.PEOPLE_ID = deleted.PEOPLE_ID
    )
    begin
      select @errno  = 60005,
             @errmsg = '%!c_data[C_TRIG_TU_PEOPLE_DB]'
      goto error
    end
  end
  /* W_1 PEOPLE may have eweb user rights in EWEB_USER_RIGHTS on PARENT UPDATE RESTRICT */
  if
    update(PEOPLE_ID)
  begin
    if exists (
      select * from deleted, <<TAB_QUAL>>.EWEB_USER_RIGHTS
      where
        <<TAB_QUAL>>.EWEB_USER_RIGHTS.PEOPLE_ID = deleted.PEOPLE_ID
    )
    begin
      select @errno  = 60005,
             @errmsg = '%!c_data[C_TRIG_TU_PEOPLE_2_DB]'
      goto error
    end
  end
  

  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_ORG_MEMBERSHIP
#REM
#REM    I_29 
#REM ******************************************************

create trigger tI_ORG_MEMBERSHIP on <<TAB_QUAL>>.ORG_MEMBERSHIP for INSERT as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* I_29 PEOPLE may be a member of ORG_MEMBERSHIP on CHILD INSERT RESTRICT */
  if
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted, <<TAB_QUAL>>.PEOPLE
        where
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60002,
             @errmsg = '%!c_data[C_TRIG_TI_ORG_MEMBER_DB]'
      goto error
    end
  end
  /* I_30 ORGANIZATION has members ORG_MEMBERSHIP on CHILD INSERT RESTRICT */
  if
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted, <<TAB_QUAL>>.ORGANIZATION
        where
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60002,
             @errmsg = '%!c_data[C_TRIG_TI_ORG_MEMBER_2_DB]'
      goto error
    end
  end
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_ORG_MEMBERSHIP
#REM
#REM    I_29 
#REM ******************************************************

create trigger tU_ORG_MEMBERSHIP on <<TAB_QUAL>>.ORG_MEMBERSHIP for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insORG_MEMBER_ID int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* I_29 PEOPLE may be a member of ORG_MEMBERSHIP on CHILD UPDATE RESTRICT */
  if
    update(PEOPLE_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted, <<TAB_QUAL>>.PEOPLE
        where
          inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60007,
             @errmsg = '%!c_data[C_TRIG_TU_ORG_MEMBER_DB]'
      goto error
    end
  end
  /* I_30 ORGANIZATION has members ORG_MEMBERSHIP on CHILD UPDATE RESTRICT */
  if
    update(ORGANIZATION_ID)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted, <<TAB_QUAL>>.ORGANIZATION
        where
          inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60007,
             @errmsg = '%!c_data[C_TRIG_TU_ORG_MEMBER_2_DB]'
      goto error
    end
  end
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_EWEB_USER_RIGHTS
#REM
#REM    W_1 
#REM ******************************************************

create trigger tI_EWEB_USER_RIGHTS on <<TAB_QUAL>>.EWEB_USER_RIGHTS for INSERT as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* PEOPLE W_1 EWEB_USER_RIGHTS ON CHILD INSERT RESTRICT */
  if update(PEOPLE_ID)
  begin

    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
      where inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID 
      
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60002,
             @errmsg = '%!c_data[C_TRIG_TI_EWEB_USR_RIGHT_DB]'
      goto error
    end

  end
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_EWEB_USER_RIGHTS
#REM
#REM    W_1 
#REM ******************************************************

create trigger tU_EWEB_USER_RIGHTS on <<TAB_QUAL>>.EWEB_USER_RIGHTS for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insPEOPLE_ID int,           
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* PEOPLE W_1 EWEB_USER_RIGHTS ON CHILD UPDATE RESTRICT */
  if update(PEOPLE_ID)
  begin

    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.PEOPLE
      where inserted.PEOPLE_ID = <<TAB_QUAL>>.PEOPLE.PEOPLE_ID 
          
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60007,
             @errmsg = '%!c_data[C_TRIG_TU_EWEB_USR_RIGHT_DB]'
      goto error
    end

  end
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tI_EWEB_ORG_RIGHTS
#REM
#REM    W_3
#REM ******************************************************

create trigger tI_EWEB_ORG_RIGHTS on <<TAB_QUAL>>.EWEB_ORG_RIGHTS for INSERT as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ORGANIZATION W_3 EWEB_ORG_RIGHTS ON CHILD INSERT RESTRICT */
  if update(ORGANIZATION_ID)
  begin

    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
      where inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID 
      
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60002,
             @errmsg = '%!c_data[C_TRIG_TI_EWEB_ORG_RIGHT_DB]'
      goto error
    end

  end
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ******************************************************
#REM    tU_EWEB_ORG_RIGHTS
#REM
#REM    W_3
#REM ******************************************************

create trigger tU_EWEB_ORG_RIGHTS on <<TAB_QUAL>>.EWEB_ORG_RIGHTS for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insORGANIZATION_ID char(15),           
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  /* ORGANIZATION W_3 EWEB_ORG_RIGHTS ON CHILD UPDATE RESTRICT */
  if update(ORGANIZATION_ID)
  begin

    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,<<TAB_QUAL>>.ORGANIZATION
      where inserted.ORGANIZATION_ID = <<TAB_QUAL>>.ORGANIZATION.ORGANIZATION_ID 
          
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 60007,
             @errmsg = '%!c_data[C_TRIG_TU_EWEB_ORG_RIGHT_DB]'
      goto error
    end

  end
  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

#REM ********************************************************
#REM End replace of constraints and triggers referencing PEOPLE
#REM ********************************************************

#REM #############################
#REM  Creating user_view for user password migration
#REM #############################

DROP VIEW <<TAB_QUAL>>.TMP2_USER_VIEW
go
DROP TABLE <<TAB_QUAL>>.TMP2_USERS
go

CREATE TABLE <<TAB_QUAL>>.TMP2_USERS
     (USER_ID                 VARCHAR(15) NOT NULL,
      LOGICAL_DELETE          INTEGER NULL,
      CONSTRAINT XPKTMP2_USERS PRIMARY KEY (USER_ID) <<PK_INDEX_CLAUSE>>,
      ) <<ON_TABLE_SEGMENT>>
go      

INSERT INTO <<TAB_QUAL>>.TMP2_USERS (USER_ID )
        SELECT USER_ID FROM <<TAB_QUAL>>.USERS
go        
        
UPDATE <<TAB_QUAL>>.TMP2_USERS SET LOGICAL_DELETE = 0
go

CREATE VIEW <<TAB_QUAL>>.TMP2_USER_VIEW
  (USER_ID,
   USER_PASSWORD,
   LOGICAL_DELETE,
   SITE_ID)
AS SELECT
   A.USER_ID,
   A.USER_PASSWORD,
   B.LOGICAL_DELETE,
   A.SITE_ID
 FROM <<TAB_QUAL>>.USERS A, <<TAB_QUAL>>.TMP2_USERS B
 WHERE A.USER_ID=B.USER_ID
go


